==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/barrel/dialogs_nl.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Greenpeace zou hier eens moeten komen kijken.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("Dat zouden die lui van Three Miles Island moeten zien, zeg.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Maar wat moeten wij ermee?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("We moeten ze allemaal uitroeien. Zulke misbaksels hebben niet het recht om dezelfde lucht, uh, hetzelfde water te ademen als wij.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Ik denk dat we de oorzaak moeten aanpakken, niet de gevolgen.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Nou ja, misschien heb je wel gelijk.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("En de oorzaak is zeker weten deze gigantische ton. Die moeten we hier weg zien te krijgen.")


dialogId("bar-m-panb", "font_small", "Yes. Let`s get to work. We can drop it on the Mr. B.`s front yard afterwards.")
dialogStr("Ja. Aan de slag. We kunnen het straks bij Meneer B. in de voortuin afleveren.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Eigenlijk zijn ze wel schattig.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn`t stand in our way so much.")
dialogStr("Als ze nou niet zo in de weg stonden.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Als ze nou daar waren waar we ze nodig hebben.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I`ll be sorry to leave.")
dialogStr("Wat een mooie verzameling monsterlijkheden. Ik ga het straks nog jammer vinden om ze achter te laten.")


dialogId("bar-m-dost0", "font_small", "That won`t happen any time soon.")
dialogStr("Dat gaat nog wel even duren.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Je zult vast wel genoeg tijd hebben om ze stuk voor stuk te bekijken.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Als we ze mee nemen en in alcohol bewaren, dan kunnen we een rariteiten kabinet beginnen.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn`t enough for you?")
dialogStr("De VDTO betaalt je niet genoeg?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Ik hoor alles!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn`t mean to offend.")
dialogStr("Sorry, baas. Zo bedoelde ik het niet.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Weet je, ik realiseer me net dat zelfs gemuteerde monsters een ziel hebben.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Misschien hebben vliegende schotels ook wel een ziel.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Ik denk dat we nooit meer hetzelfde zullen zijn, na dit veld.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Die voet is niet alleen goor maar ook schaamteloos. Moet je zien!")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Kijk eens goed naar dat dit roze ding. Het ziet er nogsteeds hetzelfde uit maar wordt steets afgrijselijker.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Het heeft zelfs moederinstincten. Moet je zien hoe het voor dat kleintje zorgt.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Ja. Het heeft het bijna vermoord met dat stalen ding daar.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Deze vis ziet er vagelijk bekend uit.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Misschien van die foto in die kerncentrale.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("De arme krab. Zo veel scharen en geen kop. Hoewel... misschien is die er beter aan toe dan wij.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Niemand is helemaal alleen als hij een klein geel badeendje heeft. Zelfs een vis niet.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Deze keer is ons doel om die ton met afval het veld uit te duwen.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Maar we moeten al die beestjes hier achter laten.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/barrel/dialogs_nl.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Greenpeace zou hier eens moeten komen kijken.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("Dit zouden die lui van Three Miles Island moeten zien, zeg.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Maar wat moeten wij ermee?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Laten we ze allemaal uitroeien. Zulke misbaksels hebben niet het recht om dezelfde lucht, uh, hetzelfde water te ademen als wij.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Dat is gemeen! Ik denk bovendien dat we de oorzaak moeten aanpakken, niet de gevolgen.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Nou ja, misschien heb je wel gelijk.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("En de oorzaak is duidelijk dit gigantische vat. Die moeten we hier weg zien te krijgen.")


dialogId("bar-m-panb", "font_small", "Yes. Let’s get to work. We can drop it on the Mr. B.’s front yard afterwards.")
dialogStr("Ja. Aan de slag. We kunnen het straks bij Meneer B. in de voortuin afleveren.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Ik begin ze nou toch wel aardig te vinden.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn’t stand in our way so much.")
dialogStr("Als ze nou niet zo in de weg stonden.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Als ze nou daar waren waar we ze nodig hebben.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I’ll be sorry to leave.")
dialogStr("Wat een mooie verzameling monsterlijkheden. Ik ga het straks nog jammer vinden om ze achter te laten.")


dialogId("bar-m-dost0", "font_small", "That won’t happen any time soon.")
dialogStr("Het duurt nog wel even voor het zover is.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Je krijg genoeg tijd om rustig van ze te genieten.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Als we ze mee nemen en in alcohol bewaren, dan kunnen we een rariteiten kabinet beginnen.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn’t enough for you?")
dialogStr("Je salaris van de VDTO is niet genoeg?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Ik hoor alles!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn’t mean to offend.")
dialogStr("Sorry, baas. Zo bedoelde ik het niet.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Weet je, ik realiseer me net dat zelfs gemuteerde monsters een ziel hebben.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Misschien hebben vliegende schotels ook wel een ziel.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Ik denk dat dit veld ons voorgoed zal veranderen.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Die voet is niet alleen vies maar ook schaamteloos. Moet je zien!")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Kijk eens goed naar dat roze ding. Het ziet er nogsteeds hetzelfde uit maar wordt toch steeds afstotelijker.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Maar het heeft zelfs moederinstincten. Moet je zien hoe het voor dat kleintje zorgt.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Ja. Het heeft het bijna vermoord met dat stalen ding daar.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Deze vis ziet er vagelijk bekend uit.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Misschien van die foto in de kerncentrale.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("Arme krab. Zo veel scharen en geen kop. Hoewel... misschien is hij er beter aan toe dan wij.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Niemand is helemaal alleen als hij een klein geel badeendje heeft. Zelfs een vis niet.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Deze keer is ons doel om dat vat met afval het veld uit te duwen.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Maar helaas zullen we al die beestjes hier achter moeten laten.  Anders kunnen ze perongeluk de gezonde populatie besmetten.")
